ico

package
v0.0.0-...-5b7c39b Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 5, 2024 License: MIT Imports: 4 Imported by: 0

Documentation

Index

Constants

const (
	// Label holds the string label denoting the ico type in the database.
	Label = "ico"
	// FieldID holds the string denoting the id field in the database.
	FieldID = "id"
	// FieldCreatedAt holds the string denoting the created_at field in the database.
	FieldCreatedAt = "created_at"
	// FieldUpdatedAt holds the string denoting the updated_at field in the database.
	FieldUpdatedAt = "updated_at"
	// FieldRoundID holds the string denoting the round_id field in the database.
	FieldRoundID = "round_id"
	// FieldRoundName holds the string denoting the round_name field in the database.
	FieldRoundName = "round_name"
	// FieldPrice holds the string denoting the price field in the database.
	FieldPrice = "price"
	// FieldNumToken holds the string denoting the num_token field in the database.
	FieldNumToken = "num_token"
	// FieldNumSub holds the string denoting the num_sub field in the database.
	FieldNumSub = "num_sub"
	// FieldPriceGap holds the string denoting the price_gap field in the database.
	FieldPriceGap = "price_gap"
	// FieldEndedAt holds the string denoting the ended_at field in the database.
	FieldEndedAt = "ended_at"
	// Table holds the table name of the ico in the database.
	Table = "icos"
)

Variables

var (
	// DefaultCreatedAt holds the default value on creation for the "created_at" field.
	DefaultCreatedAt func() time.Time
	// DefaultUpdatedAt holds the default value on creation for the "updated_at" field.
	DefaultUpdatedAt func() time.Time
	// UpdateDefaultUpdatedAt holds the default value on update for the "updated_at" field.
	UpdateDefaultUpdatedAt func() time.Time
	// DefaultID holds the default value on creation for the "id" field.
	DefaultID func() xid.ID
)

Columns holds all SQL columns for ico fields.

Functions

func And

func And(predicates ...predicate.Ico) predicate.Ico

And groups predicates with the AND operator between them.

func CreatedAt

func CreatedAt(v time.Time) predicate.Ico

CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.

func CreatedAtEQ

func CreatedAtEQ(v time.Time) predicate.Ico

CreatedAtEQ applies the EQ predicate on the "created_at" field.

func CreatedAtGT

func CreatedAtGT(v time.Time) predicate.Ico

CreatedAtGT applies the GT predicate on the "created_at" field.

func CreatedAtGTE

func CreatedAtGTE(v time.Time) predicate.Ico

CreatedAtGTE applies the GTE predicate on the "created_at" field.

func CreatedAtIn

func CreatedAtIn(vs ...time.Time) predicate.Ico

CreatedAtIn applies the In predicate on the "created_at" field.

func CreatedAtLT

func CreatedAtLT(v time.Time) predicate.Ico

CreatedAtLT applies the LT predicate on the "created_at" field.

func CreatedAtLTE

func CreatedAtLTE(v time.Time) predicate.Ico

CreatedAtLTE applies the LTE predicate on the "created_at" field.

func CreatedAtNEQ

func CreatedAtNEQ(v time.Time) predicate.Ico

CreatedAtNEQ applies the NEQ predicate on the "created_at" field.

func CreatedAtNotIn

func CreatedAtNotIn(vs ...time.Time) predicate.Ico

CreatedAtNotIn applies the NotIn predicate on the "created_at" field.

func EndedAt

func EndedAt(v time.Time) predicate.Ico

EndedAt applies equality check predicate on the "ended_at" field. It's identical to EndedAtEQ.

func EndedAtEQ

func EndedAtEQ(v time.Time) predicate.Ico

EndedAtEQ applies the EQ predicate on the "ended_at" field.

func EndedAtGT

func EndedAtGT(v time.Time) predicate.Ico

EndedAtGT applies the GT predicate on the "ended_at" field.

func EndedAtGTE

func EndedAtGTE(v time.Time) predicate.Ico

EndedAtGTE applies the GTE predicate on the "ended_at" field.

func EndedAtIn

func EndedAtIn(vs ...time.Time) predicate.Ico

EndedAtIn applies the In predicate on the "ended_at" field.

func EndedAtIsNil

func EndedAtIsNil() predicate.Ico

EndedAtIsNil applies the IsNil predicate on the "ended_at" field.

func EndedAtLT

func EndedAtLT(v time.Time) predicate.Ico

EndedAtLT applies the LT predicate on the "ended_at" field.

func EndedAtLTE

func EndedAtLTE(v time.Time) predicate.Ico

EndedAtLTE applies the LTE predicate on the "ended_at" field.

func EndedAtNEQ

func EndedAtNEQ(v time.Time) predicate.Ico

EndedAtNEQ applies the NEQ predicate on the "ended_at" field.

func EndedAtNotIn

func EndedAtNotIn(vs ...time.Time) predicate.Ico

EndedAtNotIn applies the NotIn predicate on the "ended_at" field.

func EndedAtNotNil

func EndedAtNotNil() predicate.Ico

EndedAtNotNil applies the NotNil predicate on the "ended_at" field.

func ID

func ID(id xid.ID) predicate.Ico

ID filters vertices based on their ID field.

func IDEQ

func IDEQ(id xid.ID) predicate.Ico

IDEQ applies the EQ predicate on the ID field.

func IDGT

func IDGT(id xid.ID) predicate.Ico

IDGT applies the GT predicate on the ID field.

func IDGTE

func IDGTE(id xid.ID) predicate.Ico

IDGTE applies the GTE predicate on the ID field.

func IDIn

func IDIn(ids ...xid.ID) predicate.Ico

IDIn applies the In predicate on the ID field.

func IDLT

func IDLT(id xid.ID) predicate.Ico

IDLT applies the LT predicate on the ID field.

func IDLTE

func IDLTE(id xid.ID) predicate.Ico

IDLTE applies the LTE predicate on the ID field.

func IDNEQ

func IDNEQ(id xid.ID) predicate.Ico

IDNEQ applies the NEQ predicate on the ID field.

func IDNotIn

func IDNotIn(ids ...xid.ID) predicate.Ico

IDNotIn applies the NotIn predicate on the ID field.

func Not

func Not(p predicate.Ico) predicate.Ico

Not applies the not operator on the given predicate.

func NumSub

func NumSub(v int32) predicate.Ico

NumSub applies equality check predicate on the "num_sub" field. It's identical to NumSubEQ.

func NumSubEQ

func NumSubEQ(v int32) predicate.Ico

NumSubEQ applies the EQ predicate on the "num_sub" field.

func NumSubGT

func NumSubGT(v int32) predicate.Ico

NumSubGT applies the GT predicate on the "num_sub" field.

func NumSubGTE

func NumSubGTE(v int32) predicate.Ico

NumSubGTE applies the GTE predicate on the "num_sub" field.

func NumSubIn

func NumSubIn(vs ...int32) predicate.Ico

NumSubIn applies the In predicate on the "num_sub" field.

func NumSubLT

func NumSubLT(v int32) predicate.Ico

NumSubLT applies the LT predicate on the "num_sub" field.

func NumSubLTE

func NumSubLTE(v int32) predicate.Ico

NumSubLTE applies the LTE predicate on the "num_sub" field.

func NumSubNEQ

func NumSubNEQ(v int32) predicate.Ico

NumSubNEQ applies the NEQ predicate on the "num_sub" field.

func NumSubNotIn

func NumSubNotIn(vs ...int32) predicate.Ico

NumSubNotIn applies the NotIn predicate on the "num_sub" field.

func NumToken

func NumToken(v string) predicate.Ico

NumToken applies equality check predicate on the "num_token" field. It's identical to NumTokenEQ.

func NumTokenContains

func NumTokenContains(v string) predicate.Ico

NumTokenContains applies the Contains predicate on the "num_token" field.

func NumTokenContainsFold

func NumTokenContainsFold(v string) predicate.Ico

NumTokenContainsFold applies the ContainsFold predicate on the "num_token" field.

func NumTokenEQ

func NumTokenEQ(v string) predicate.Ico

NumTokenEQ applies the EQ predicate on the "num_token" field.

func NumTokenEqualFold

func NumTokenEqualFold(v string) predicate.Ico

NumTokenEqualFold applies the EqualFold predicate on the "num_token" field.

func NumTokenGT

func NumTokenGT(v string) predicate.Ico

NumTokenGT applies the GT predicate on the "num_token" field.

func NumTokenGTE

func NumTokenGTE(v string) predicate.Ico

NumTokenGTE applies the GTE predicate on the "num_token" field.

func NumTokenHasPrefix

func NumTokenHasPrefix(v string) predicate.Ico

NumTokenHasPrefix applies the HasPrefix predicate on the "num_token" field.

func NumTokenHasSuffix

func NumTokenHasSuffix(v string) predicate.Ico

NumTokenHasSuffix applies the HasSuffix predicate on the "num_token" field.

func NumTokenIn

func NumTokenIn(vs ...string) predicate.Ico

NumTokenIn applies the In predicate on the "num_token" field.

func NumTokenLT

func NumTokenLT(v string) predicate.Ico

NumTokenLT applies the LT predicate on the "num_token" field.

func NumTokenLTE

func NumTokenLTE(v string) predicate.Ico

NumTokenLTE applies the LTE predicate on the "num_token" field.

func NumTokenNEQ

func NumTokenNEQ(v string) predicate.Ico

NumTokenNEQ applies the NEQ predicate on the "num_token" field.

func NumTokenNotIn

func NumTokenNotIn(vs ...string) predicate.Ico

NumTokenNotIn applies the NotIn predicate on the "num_token" field.

func Or

func Or(predicates ...predicate.Ico) predicate.Ico

Or groups predicates with the OR operator between them.

func Price

func Price(v string) predicate.Ico

Price applies equality check predicate on the "price" field. It's identical to PriceEQ.

func PriceContains

func PriceContains(v string) predicate.Ico

PriceContains applies the Contains predicate on the "price" field.

func PriceContainsFold

func PriceContainsFold(v string) predicate.Ico

PriceContainsFold applies the ContainsFold predicate on the "price" field.

func PriceEQ

func PriceEQ(v string) predicate.Ico

PriceEQ applies the EQ predicate on the "price" field.

func PriceEqualFold

func PriceEqualFold(v string) predicate.Ico

PriceEqualFold applies the EqualFold predicate on the "price" field.

func PriceGT

func PriceGT(v string) predicate.Ico

PriceGT applies the GT predicate on the "price" field.

func PriceGTE

func PriceGTE(v string) predicate.Ico

PriceGTE applies the GTE predicate on the "price" field.

func PriceGap

func PriceGap(v string) predicate.Ico

PriceGap applies equality check predicate on the "price_gap" field. It's identical to PriceGapEQ.

func PriceGapContains

func PriceGapContains(v string) predicate.Ico

PriceGapContains applies the Contains predicate on the "price_gap" field.

func PriceGapContainsFold

func PriceGapContainsFold(v string) predicate.Ico

PriceGapContainsFold applies the ContainsFold predicate on the "price_gap" field.

func PriceGapEQ

func PriceGapEQ(v string) predicate.Ico

PriceGapEQ applies the EQ predicate on the "price_gap" field.

func PriceGapEqualFold

func PriceGapEqualFold(v string) predicate.Ico

PriceGapEqualFold applies the EqualFold predicate on the "price_gap" field.

func PriceGapGT

func PriceGapGT(v string) predicate.Ico

PriceGapGT applies the GT predicate on the "price_gap" field.

func PriceGapGTE

func PriceGapGTE(v string) predicate.Ico

PriceGapGTE applies the GTE predicate on the "price_gap" field.

func PriceGapHasPrefix

func PriceGapHasPrefix(v string) predicate.Ico

PriceGapHasPrefix applies the HasPrefix predicate on the "price_gap" field.

func PriceGapHasSuffix

func PriceGapHasSuffix(v string) predicate.Ico

PriceGapHasSuffix applies the HasSuffix predicate on the "price_gap" field.

func PriceGapIn

func PriceGapIn(vs ...string) predicate.Ico

PriceGapIn applies the In predicate on the "price_gap" field.

func PriceGapLT

func PriceGapLT(v string) predicate.Ico

PriceGapLT applies the LT predicate on the "price_gap" field.

func PriceGapLTE

func PriceGapLTE(v string) predicate.Ico

PriceGapLTE applies the LTE predicate on the "price_gap" field.

func PriceGapNEQ

func PriceGapNEQ(v string) predicate.Ico

PriceGapNEQ applies the NEQ predicate on the "price_gap" field.

func PriceGapNotIn

func PriceGapNotIn(vs ...string) predicate.Ico

PriceGapNotIn applies the NotIn predicate on the "price_gap" field.

func PriceHasPrefix

func PriceHasPrefix(v string) predicate.Ico

PriceHasPrefix applies the HasPrefix predicate on the "price" field.

func PriceHasSuffix

func PriceHasSuffix(v string) predicate.Ico

PriceHasSuffix applies the HasSuffix predicate on the "price" field.

func PriceIn

func PriceIn(vs ...string) predicate.Ico

PriceIn applies the In predicate on the "price" field.

func PriceLT

func PriceLT(v string) predicate.Ico

PriceLT applies the LT predicate on the "price" field.

func PriceLTE

func PriceLTE(v string) predicate.Ico

PriceLTE applies the LTE predicate on the "price" field.

func PriceNEQ

func PriceNEQ(v string) predicate.Ico

PriceNEQ applies the NEQ predicate on the "price" field.

func PriceNotIn

func PriceNotIn(vs ...string) predicate.Ico

PriceNotIn applies the NotIn predicate on the "price" field.

func RoundID

func RoundID(v int32) predicate.Ico

RoundID applies equality check predicate on the "round_id" field. It's identical to RoundIDEQ.

func RoundIDEQ

func RoundIDEQ(v int32) predicate.Ico

RoundIDEQ applies the EQ predicate on the "round_id" field.

func RoundIDGT

func RoundIDGT(v int32) predicate.Ico

RoundIDGT applies the GT predicate on the "round_id" field.

func RoundIDGTE

func RoundIDGTE(v int32) predicate.Ico

RoundIDGTE applies the GTE predicate on the "round_id" field.

func RoundIDIn

func RoundIDIn(vs ...int32) predicate.Ico

RoundIDIn applies the In predicate on the "round_id" field.

func RoundIDLT

func RoundIDLT(v int32) predicate.Ico

RoundIDLT applies the LT predicate on the "round_id" field.

func RoundIDLTE

func RoundIDLTE(v int32) predicate.Ico

RoundIDLTE applies the LTE predicate on the "round_id" field.

func RoundIDNEQ

func RoundIDNEQ(v int32) predicate.Ico

RoundIDNEQ applies the NEQ predicate on the "round_id" field.

func RoundIDNotIn

func RoundIDNotIn(vs ...int32) predicate.Ico

RoundIDNotIn applies the NotIn predicate on the "round_id" field.

func RoundName

func RoundName(v string) predicate.Ico

RoundName applies equality check predicate on the "round_name" field. It's identical to RoundNameEQ.

func RoundNameContains

func RoundNameContains(v string) predicate.Ico

RoundNameContains applies the Contains predicate on the "round_name" field.

func RoundNameContainsFold

func RoundNameContainsFold(v string) predicate.Ico

RoundNameContainsFold applies the ContainsFold predicate on the "round_name" field.

func RoundNameEQ

func RoundNameEQ(v string) predicate.Ico

RoundNameEQ applies the EQ predicate on the "round_name" field.

func RoundNameEqualFold

func RoundNameEqualFold(v string) predicate.Ico

RoundNameEqualFold applies the EqualFold predicate on the "round_name" field.

func RoundNameGT

func RoundNameGT(v string) predicate.Ico

RoundNameGT applies the GT predicate on the "round_name" field.

func RoundNameGTE

func RoundNameGTE(v string) predicate.Ico

RoundNameGTE applies the GTE predicate on the "round_name" field.

func RoundNameHasPrefix

func RoundNameHasPrefix(v string) predicate.Ico

RoundNameHasPrefix applies the HasPrefix predicate on the "round_name" field.

func RoundNameHasSuffix

func RoundNameHasSuffix(v string) predicate.Ico

RoundNameHasSuffix applies the HasSuffix predicate on the "round_name" field.

func RoundNameIn

func RoundNameIn(vs ...string) predicate.Ico

RoundNameIn applies the In predicate on the "round_name" field.

func RoundNameLT

func RoundNameLT(v string) predicate.Ico

RoundNameLT applies the LT predicate on the "round_name" field.

func RoundNameLTE

func RoundNameLTE(v string) predicate.Ico

RoundNameLTE applies the LTE predicate on the "round_name" field.

func RoundNameNEQ

func RoundNameNEQ(v string) predicate.Ico

RoundNameNEQ applies the NEQ predicate on the "round_name" field.

func RoundNameNotIn

func RoundNameNotIn(vs ...string) predicate.Ico

RoundNameNotIn applies the NotIn predicate on the "round_name" field.

func UpdatedAt

func UpdatedAt(v time.Time) predicate.Ico

UpdatedAt applies equality check predicate on the "updated_at" field. It's identical to UpdatedAtEQ.

func UpdatedAtEQ

func UpdatedAtEQ(v time.Time) predicate.Ico

UpdatedAtEQ applies the EQ predicate on the "updated_at" field.

func UpdatedAtGT

func UpdatedAtGT(v time.Time) predicate.Ico

UpdatedAtGT applies the GT predicate on the "updated_at" field.

func UpdatedAtGTE

func UpdatedAtGTE(v time.Time) predicate.Ico

UpdatedAtGTE applies the GTE predicate on the "updated_at" field.

func UpdatedAtIn

func UpdatedAtIn(vs ...time.Time) predicate.Ico

UpdatedAtIn applies the In predicate on the "updated_at" field.

func UpdatedAtLT

func UpdatedAtLT(v time.Time) predicate.Ico

UpdatedAtLT applies the LT predicate on the "updated_at" field.

func UpdatedAtLTE

func UpdatedAtLTE(v time.Time) predicate.Ico

UpdatedAtLTE applies the LTE predicate on the "updated_at" field.

func UpdatedAtNEQ

func UpdatedAtNEQ(v time.Time) predicate.Ico

UpdatedAtNEQ applies the NEQ predicate on the "updated_at" field.

func UpdatedAtNotIn

func UpdatedAtNotIn(vs ...time.Time) predicate.Ico

UpdatedAtNotIn applies the NotIn predicate on the "updated_at" field.

func ValidColumn

func ValidColumn(column string) bool

ValidColumn reports if the column name is valid (part of the table columns).

Types

type OrderOption

type OrderOption func(*sql.Selector)

OrderOption defines the ordering options for the Ico queries.

func ByCreatedAt

func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption

ByCreatedAt orders the results by the created_at field.

func ByEndedAt

func ByEndedAt(opts ...sql.OrderTermOption) OrderOption

ByEndedAt orders the results by the ended_at field.

func ByID

func ByID(opts ...sql.OrderTermOption) OrderOption

ByID orders the results by the id field.

func ByNumSub

func ByNumSub(opts ...sql.OrderTermOption) OrderOption

ByNumSub orders the results by the num_sub field.

func ByNumToken

func ByNumToken(opts ...sql.OrderTermOption) OrderOption

ByNumToken orders the results by the num_token field.

func ByPrice

func ByPrice(opts ...sql.OrderTermOption) OrderOption

ByPrice orders the results by the price field.

func ByPriceGap

func ByPriceGap(opts ...sql.OrderTermOption) OrderOption

ByPriceGap orders the results by the price_gap field.

func ByRoundID

func ByRoundID(opts ...sql.OrderTermOption) OrderOption

ByRoundID orders the results by the round_id field.

func ByRoundName

func ByRoundName(opts ...sql.OrderTermOption) OrderOption

ByRoundName orders the results by the round_name field.

func ByUpdatedAt

func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption

ByUpdatedAt orders the results by the updated_at field.

Jump to