Documentation
¶
Index ¶
- Constants
- Variables
- func And(predicates ...predicate.Ico) predicate.Ico
- func CreatedAt(v time.Time) predicate.Ico
- func CreatedAtEQ(v time.Time) predicate.Ico
- func CreatedAtGT(v time.Time) predicate.Ico
- func CreatedAtGTE(v time.Time) predicate.Ico
- func CreatedAtIn(vs ...time.Time) predicate.Ico
- func CreatedAtLT(v time.Time) predicate.Ico
- func CreatedAtLTE(v time.Time) predicate.Ico
- func CreatedAtNEQ(v time.Time) predicate.Ico
- func CreatedAtNotIn(vs ...time.Time) predicate.Ico
- func EndedAt(v time.Time) predicate.Ico
- func EndedAtEQ(v time.Time) predicate.Ico
- func EndedAtGT(v time.Time) predicate.Ico
- func EndedAtGTE(v time.Time) predicate.Ico
- func EndedAtIn(vs ...time.Time) predicate.Ico
- func EndedAtIsNil() predicate.Ico
- func EndedAtLT(v time.Time) predicate.Ico
- func EndedAtLTE(v time.Time) predicate.Ico
- func EndedAtNEQ(v time.Time) predicate.Ico
- func EndedAtNotIn(vs ...time.Time) predicate.Ico
- func EndedAtNotNil() predicate.Ico
- func ID(id xid.ID) predicate.Ico
- func IDEQ(id xid.ID) predicate.Ico
- func IDGT(id xid.ID) predicate.Ico
- func IDGTE(id xid.ID) predicate.Ico
- func IDIn(ids ...xid.ID) predicate.Ico
- func IDLT(id xid.ID) predicate.Ico
- func IDLTE(id xid.ID) predicate.Ico
- func IDNEQ(id xid.ID) predicate.Ico
- func IDNotIn(ids ...xid.ID) predicate.Ico
- func Not(p predicate.Ico) predicate.Ico
- func NumSub(v int32) predicate.Ico
- func NumSubEQ(v int32) predicate.Ico
- func NumSubGT(v int32) predicate.Ico
- func NumSubGTE(v int32) predicate.Ico
- func NumSubIn(vs ...int32) predicate.Ico
- func NumSubLT(v int32) predicate.Ico
- func NumSubLTE(v int32) predicate.Ico
- func NumSubNEQ(v int32) predicate.Ico
- func NumSubNotIn(vs ...int32) predicate.Ico
- func NumToken(v string) predicate.Ico
- func NumTokenContains(v string) predicate.Ico
- func NumTokenContainsFold(v string) predicate.Ico
- func NumTokenEQ(v string) predicate.Ico
- func NumTokenEqualFold(v string) predicate.Ico
- func NumTokenGT(v string) predicate.Ico
- func NumTokenGTE(v string) predicate.Ico
- func NumTokenHasPrefix(v string) predicate.Ico
- func NumTokenHasSuffix(v string) predicate.Ico
- func NumTokenIn(vs ...string) predicate.Ico
- func NumTokenLT(v string) predicate.Ico
- func NumTokenLTE(v string) predicate.Ico
- func NumTokenNEQ(v string) predicate.Ico
- func NumTokenNotIn(vs ...string) predicate.Ico
- func Or(predicates ...predicate.Ico) predicate.Ico
- func Price(v string) predicate.Ico
- func PriceContains(v string) predicate.Ico
- func PriceContainsFold(v string) predicate.Ico
- func PriceEQ(v string) predicate.Ico
- func PriceEqualFold(v string) predicate.Ico
- func PriceGT(v string) predicate.Ico
- func PriceGTE(v string) predicate.Ico
- func PriceGap(v string) predicate.Ico
- func PriceGapContains(v string) predicate.Ico
- func PriceGapContainsFold(v string) predicate.Ico
- func PriceGapEQ(v string) predicate.Ico
- func PriceGapEqualFold(v string) predicate.Ico
- func PriceGapGT(v string) predicate.Ico
- func PriceGapGTE(v string) predicate.Ico
- func PriceGapHasPrefix(v string) predicate.Ico
- func PriceGapHasSuffix(v string) predicate.Ico
- func PriceGapIn(vs ...string) predicate.Ico
- func PriceGapLT(v string) predicate.Ico
- func PriceGapLTE(v string) predicate.Ico
- func PriceGapNEQ(v string) predicate.Ico
- func PriceGapNotIn(vs ...string) predicate.Ico
- func PriceHasPrefix(v string) predicate.Ico
- func PriceHasSuffix(v string) predicate.Ico
- func PriceIn(vs ...string) predicate.Ico
- func PriceLT(v string) predicate.Ico
- func PriceLTE(v string) predicate.Ico
- func PriceNEQ(v string) predicate.Ico
- func PriceNotIn(vs ...string) predicate.Ico
- func RoundID(v int32) predicate.Ico
- func RoundIDEQ(v int32) predicate.Ico
- func RoundIDGT(v int32) predicate.Ico
- func RoundIDGTE(v int32) predicate.Ico
- func RoundIDIn(vs ...int32) predicate.Ico
- func RoundIDLT(v int32) predicate.Ico
- func RoundIDLTE(v int32) predicate.Ico
- func RoundIDNEQ(v int32) predicate.Ico
- func RoundIDNotIn(vs ...int32) predicate.Ico
- func RoundName(v string) predicate.Ico
- func RoundNameContains(v string) predicate.Ico
- func RoundNameContainsFold(v string) predicate.Ico
- func RoundNameEQ(v string) predicate.Ico
- func RoundNameEqualFold(v string) predicate.Ico
- func RoundNameGT(v string) predicate.Ico
- func RoundNameGTE(v string) predicate.Ico
- func RoundNameHasPrefix(v string) predicate.Ico
- func RoundNameHasSuffix(v string) predicate.Ico
- func RoundNameIn(vs ...string) predicate.Ico
- func RoundNameLT(v string) predicate.Ico
- func RoundNameLTE(v string) predicate.Ico
- func RoundNameNEQ(v string) predicate.Ico
- func RoundNameNotIn(vs ...string) predicate.Ico
- func UpdatedAt(v time.Time) predicate.Ico
- func UpdatedAtEQ(v time.Time) predicate.Ico
- func UpdatedAtGT(v time.Time) predicate.Ico
- func UpdatedAtGTE(v time.Time) predicate.Ico
- func UpdatedAtIn(vs ...time.Time) predicate.Ico
- func UpdatedAtLT(v time.Time) predicate.Ico
- func UpdatedAtLTE(v time.Time) predicate.Ico
- func UpdatedAtNEQ(v time.Time) predicate.Ico
- func UpdatedAtNotIn(vs ...time.Time) predicate.Ico
- func ValidColumn(column string) bool
- type OrderOption
- func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption
- func ByEndedAt(opts ...sql.OrderTermOption) OrderOption
- func ByID(opts ...sql.OrderTermOption) OrderOption
- func ByNumSub(opts ...sql.OrderTermOption) OrderOption
- func ByNumToken(opts ...sql.OrderTermOption) OrderOption
- func ByPrice(opts ...sql.OrderTermOption) OrderOption
- func ByPriceGap(opts ...sql.OrderTermOption) OrderOption
- func ByRoundID(opts ...sql.OrderTermOption) OrderOption
- func ByRoundName(opts ...sql.OrderTermOption) OrderOption
- func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption
Constants ¶
const ( // Label holds the string label denoting the ico type in the database. Label = "ico" // FieldID holds the string denoting the id field in the database. FieldID = "id" // FieldCreatedAt holds the string denoting the created_at field in the database. FieldCreatedAt = "created_at" // FieldUpdatedAt holds the string denoting the updated_at field in the database. FieldUpdatedAt = "updated_at" // FieldRoundID holds the string denoting the round_id field in the database. FieldRoundID = "round_id" // FieldRoundName holds the string denoting the round_name field in the database. FieldRoundName = "round_name" // FieldPrice holds the string denoting the price field in the database. FieldPrice = "price" // FieldNumToken holds the string denoting the num_token field in the database. FieldNumToken = "num_token" // FieldNumSub holds the string denoting the num_sub field in the database. FieldNumSub = "num_sub" // FieldPriceGap holds the string denoting the price_gap field in the database. FieldPriceGap = "price_gap" // FieldEndedAt holds the string denoting the ended_at field in the database. FieldEndedAt = "ended_at" // Table holds the table name of the ico in the database. Table = "icos" )
Variables ¶
var ( // DefaultCreatedAt holds the default value on creation for the "created_at" field. DefaultCreatedAt func() time.Time // DefaultUpdatedAt holds the default value on creation for the "updated_at" field. DefaultUpdatedAt func() time.Time // UpdateDefaultUpdatedAt holds the default value on update for the "updated_at" field. UpdateDefaultUpdatedAt func() time.Time // DefaultID holds the default value on creation for the "id" field. DefaultID func() xid.ID )
var Columns = []string{ FieldID, FieldCreatedAt, FieldUpdatedAt, FieldRoundID, FieldRoundName, FieldPrice, FieldNumToken, FieldNumSub, FieldPriceGap, FieldEndedAt, }
Columns holds all SQL columns for ico fields.
Functions ¶
func CreatedAt ¶
CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.
func CreatedAtEQ ¶
CreatedAtEQ applies the EQ predicate on the "created_at" field.
func CreatedAtGT ¶
CreatedAtGT applies the GT predicate on the "created_at" field.
func CreatedAtGTE ¶
CreatedAtGTE applies the GTE predicate on the "created_at" field.
func CreatedAtIn ¶
CreatedAtIn applies the In predicate on the "created_at" field.
func CreatedAtLT ¶
CreatedAtLT applies the LT predicate on the "created_at" field.
func CreatedAtLTE ¶
CreatedAtLTE applies the LTE predicate on the "created_at" field.
func CreatedAtNEQ ¶
CreatedAtNEQ applies the NEQ predicate on the "created_at" field.
func CreatedAtNotIn ¶
CreatedAtNotIn applies the NotIn predicate on the "created_at" field.
func EndedAt ¶
EndedAt applies equality check predicate on the "ended_at" field. It's identical to EndedAtEQ.
func EndedAtGTE ¶
EndedAtGTE applies the GTE predicate on the "ended_at" field.
func EndedAtIsNil ¶
EndedAtIsNil applies the IsNil predicate on the "ended_at" field.
func EndedAtLTE ¶
EndedAtLTE applies the LTE predicate on the "ended_at" field.
func EndedAtNEQ ¶
EndedAtNEQ applies the NEQ predicate on the "ended_at" field.
func EndedAtNotIn ¶
EndedAtNotIn applies the NotIn predicate on the "ended_at" field.
func EndedAtNotNil ¶
EndedAtNotNil applies the NotNil predicate on the "ended_at" field.
func NumSub ¶
NumSub applies equality check predicate on the "num_sub" field. It's identical to NumSubEQ.
func NumSubNotIn ¶
NumSubNotIn applies the NotIn predicate on the "num_sub" field.
func NumToken ¶
NumToken applies equality check predicate on the "num_token" field. It's identical to NumTokenEQ.
func NumTokenContains ¶
NumTokenContains applies the Contains predicate on the "num_token" field.
func NumTokenContainsFold ¶
NumTokenContainsFold applies the ContainsFold predicate on the "num_token" field.
func NumTokenEQ ¶
NumTokenEQ applies the EQ predicate on the "num_token" field.
func NumTokenEqualFold ¶
NumTokenEqualFold applies the EqualFold predicate on the "num_token" field.
func NumTokenGT ¶
NumTokenGT applies the GT predicate on the "num_token" field.
func NumTokenGTE ¶
NumTokenGTE applies the GTE predicate on the "num_token" field.
func NumTokenHasPrefix ¶
NumTokenHasPrefix applies the HasPrefix predicate on the "num_token" field.
func NumTokenHasSuffix ¶
NumTokenHasSuffix applies the HasSuffix predicate on the "num_token" field.
func NumTokenIn ¶
NumTokenIn applies the In predicate on the "num_token" field.
func NumTokenLT ¶
NumTokenLT applies the LT predicate on the "num_token" field.
func NumTokenLTE ¶
NumTokenLTE applies the LTE predicate on the "num_token" field.
func NumTokenNEQ ¶
NumTokenNEQ applies the NEQ predicate on the "num_token" field.
func NumTokenNotIn ¶
NumTokenNotIn applies the NotIn predicate on the "num_token" field.
func Price ¶
Price applies equality check predicate on the "price" field. It's identical to PriceEQ.
func PriceContains ¶
PriceContains applies the Contains predicate on the "price" field.
func PriceContainsFold ¶
PriceContainsFold applies the ContainsFold predicate on the "price" field.
func PriceEqualFold ¶
PriceEqualFold applies the EqualFold predicate on the "price" field.
func PriceGap ¶
PriceGap applies equality check predicate on the "price_gap" field. It's identical to PriceGapEQ.
func PriceGapContains ¶
PriceGapContains applies the Contains predicate on the "price_gap" field.
func PriceGapContainsFold ¶
PriceGapContainsFold applies the ContainsFold predicate on the "price_gap" field.
func PriceGapEQ ¶
PriceGapEQ applies the EQ predicate on the "price_gap" field.
func PriceGapEqualFold ¶
PriceGapEqualFold applies the EqualFold predicate on the "price_gap" field.
func PriceGapGT ¶
PriceGapGT applies the GT predicate on the "price_gap" field.
func PriceGapGTE ¶
PriceGapGTE applies the GTE predicate on the "price_gap" field.
func PriceGapHasPrefix ¶
PriceGapHasPrefix applies the HasPrefix predicate on the "price_gap" field.
func PriceGapHasSuffix ¶
PriceGapHasSuffix applies the HasSuffix predicate on the "price_gap" field.
func PriceGapIn ¶
PriceGapIn applies the In predicate on the "price_gap" field.
func PriceGapLT ¶
PriceGapLT applies the LT predicate on the "price_gap" field.
func PriceGapLTE ¶
PriceGapLTE applies the LTE predicate on the "price_gap" field.
func PriceGapNEQ ¶
PriceGapNEQ applies the NEQ predicate on the "price_gap" field.
func PriceGapNotIn ¶
PriceGapNotIn applies the NotIn predicate on the "price_gap" field.
func PriceHasPrefix ¶
PriceHasPrefix applies the HasPrefix predicate on the "price" field.
func PriceHasSuffix ¶
PriceHasSuffix applies the HasSuffix predicate on the "price" field.
func PriceNotIn ¶
PriceNotIn applies the NotIn predicate on the "price" field.
func RoundID ¶
RoundID applies equality check predicate on the "round_id" field. It's identical to RoundIDEQ.
func RoundIDGTE ¶
RoundIDGTE applies the GTE predicate on the "round_id" field.
func RoundIDLTE ¶
RoundIDLTE applies the LTE predicate on the "round_id" field.
func RoundIDNEQ ¶
RoundIDNEQ applies the NEQ predicate on the "round_id" field.
func RoundIDNotIn ¶
RoundIDNotIn applies the NotIn predicate on the "round_id" field.
func RoundName ¶
RoundName applies equality check predicate on the "round_name" field. It's identical to RoundNameEQ.
func RoundNameContains ¶
RoundNameContains applies the Contains predicate on the "round_name" field.
func RoundNameContainsFold ¶
RoundNameContainsFold applies the ContainsFold predicate on the "round_name" field.
func RoundNameEQ ¶
RoundNameEQ applies the EQ predicate on the "round_name" field.
func RoundNameEqualFold ¶
RoundNameEqualFold applies the EqualFold predicate on the "round_name" field.
func RoundNameGT ¶
RoundNameGT applies the GT predicate on the "round_name" field.
func RoundNameGTE ¶
RoundNameGTE applies the GTE predicate on the "round_name" field.
func RoundNameHasPrefix ¶
RoundNameHasPrefix applies the HasPrefix predicate on the "round_name" field.
func RoundNameHasSuffix ¶
RoundNameHasSuffix applies the HasSuffix predicate on the "round_name" field.
func RoundNameIn ¶
RoundNameIn applies the In predicate on the "round_name" field.
func RoundNameLT ¶
RoundNameLT applies the LT predicate on the "round_name" field.
func RoundNameLTE ¶
RoundNameLTE applies the LTE predicate on the "round_name" field.
func RoundNameNEQ ¶
RoundNameNEQ applies the NEQ predicate on the "round_name" field.
func RoundNameNotIn ¶
RoundNameNotIn applies the NotIn predicate on the "round_name" field.
func UpdatedAt ¶
UpdatedAt applies equality check predicate on the "updated_at" field. It's identical to UpdatedAtEQ.
func UpdatedAtEQ ¶
UpdatedAtEQ applies the EQ predicate on the "updated_at" field.
func UpdatedAtGT ¶
UpdatedAtGT applies the GT predicate on the "updated_at" field.
func UpdatedAtGTE ¶
UpdatedAtGTE applies the GTE predicate on the "updated_at" field.
func UpdatedAtIn ¶
UpdatedAtIn applies the In predicate on the "updated_at" field.
func UpdatedAtLT ¶
UpdatedAtLT applies the LT predicate on the "updated_at" field.
func UpdatedAtLTE ¶
UpdatedAtLTE applies the LTE predicate on the "updated_at" field.
func UpdatedAtNEQ ¶
UpdatedAtNEQ applies the NEQ predicate on the "updated_at" field.
func UpdatedAtNotIn ¶
UpdatedAtNotIn applies the NotIn predicate on the "updated_at" field.
func ValidColumn ¶
ValidColumn reports if the column name is valid (part of the table columns).
Types ¶
type OrderOption ¶
OrderOption defines the ordering options for the Ico queries.
func ByCreatedAt ¶
func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption
ByCreatedAt orders the results by the created_at field.
func ByEndedAt ¶
func ByEndedAt(opts ...sql.OrderTermOption) OrderOption
ByEndedAt orders the results by the ended_at field.
func ByID ¶
func ByID(opts ...sql.OrderTermOption) OrderOption
ByID orders the results by the id field.
func ByNumSub ¶
func ByNumSub(opts ...sql.OrderTermOption) OrderOption
ByNumSub orders the results by the num_sub field.
func ByNumToken ¶
func ByNumToken(opts ...sql.OrderTermOption) OrderOption
ByNumToken orders the results by the num_token field.
func ByPrice ¶
func ByPrice(opts ...sql.OrderTermOption) OrderOption
ByPrice orders the results by the price field.
func ByPriceGap ¶
func ByPriceGap(opts ...sql.OrderTermOption) OrderOption
ByPriceGap orders the results by the price_gap field.
func ByRoundID ¶
func ByRoundID(opts ...sql.OrderTermOption) OrderOption
ByRoundID orders the results by the round_id field.
func ByRoundName ¶
func ByRoundName(opts ...sql.OrderTermOption) OrderOption
ByRoundName orders the results by the round_name field.
func ByUpdatedAt ¶
func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption
ByUpdatedAt orders the results by the updated_at field.